==> HinemosWebClient_src-1.0.0.tar.gz: HinemosWebClient_src-1.0.0/src/com/necsoft/hinemos/webclient/jobmanagement/form/HistoryForm.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.jobmanagement.form;

import com.necsoft.hinemos.webclient.form.GridForm;

public class HistoryForm extends GridForm {
    private boolean filter;

    private String startFromDate;

    private String endFromDate;

    private String startToDate;

    private String endToDate;

    private String jobId;

    private String status;

    private String triggerType;

    private String triggerInfo;

    public boolean isFilter() {
        return filter;
    }

    /**
     * @return the startFromDate
     */
    public String getStartFromDate() {
        return startFromDate;
    }

    /**
     * @param startFromDate
     *            the startFromDate to set
     */
    public void setStartFromDate(String startFromDate) {
        this.startFromDate = startFromDate;
    }

    /**
     * @return the endFromDate
     */
    public String getEndFromDate() {
        return endFromDate;
    }

    /**
     * @param endFromDate
     *            the endFromDate to set
     */
    public void setEndFromDate(String endFromDate) {
        this.endFromDate = endFromDate;
    }

    /**
     * @return the startToDate
     */
    public String getStartToDate() {
        return startToDate;
    }

    /**
     * @param startToDate
     *            the startToDate to set
     */
    public void setStartToDate(String startToDate) {
        this.startToDate = startToDate;
    }

    /**
     * @return the endToDate
     */
    public String getEndToDate() {
        return endToDate;
    }

    /**
     * @param endToDate
     *            the endToDate to set
     */
    public void setEndToDate(String endToDate) {
        this.endToDate = endToDate;
    }

    /**
     * @return the jobId
     */
    public String getJobId() {
        return jobId;
    }

    /**
     * @param jobId
     *            the jobId to set
     */
    public void setJobId(String jobId) {
        this.jobId = jobId;
    }

    /**
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * @param status
     *            the status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * @return the triggerType
     */
    public String getTriggerType() {
        return triggerType;
    }

    /**
     * @param triggerType
     *            the triggerType to set
     */
    public void setTriggerType(String triggerType) {
        this.triggerType = triggerType;
    }

    /**
     * @return the triggerInfo
     */
    public String getTriggerInfo() {
        return triggerInfo;
    }

    /**
     * @param triggerInfo
     *            the triggerInfo to set
     */
    public void setTriggerInfo(String triggerInfo) {
        this.triggerInfo = triggerInfo;
    }

    /**
     * @param filter
     *            the filter to set
     */
    public void setFilter(boolean filter) {
        this.filter = filter;
    }
}

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/src/com/necsoft/hinemos/webclient/jobmanagement/form/HistoryForm.java <==
/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.jobmanagement.form;

import com.necsoft.hinemos.webclient.form.GridForm;

public class HistoryForm extends GridForm {
    private boolean filter;

    private String startFromDate;

    private String endFromDate;

    private String startToDate;

    private String endToDate;

    private String jobId;
    
    private String jobManager;

    private String status;

    private String triggerType;

    private String triggerInfo;

    public boolean isFilter() {
        return filter;
    }

    /**
     * @return the startFromDate
     */
    public String getStartFromDate() {
        return startFromDate;
    }

    /**
     * @param startFromDate
     *            the startFromDate to set
     */
    public void setStartFromDate(String startFromDate) {
        this.startFromDate = startFromDate;
    }

    /**
     * @return the endFromDate
     */
    public String getEndFromDate() {
        return endFromDate;
    }

    /**
     * @param endFromDate
     *            the endFromDate to set
     */
    public void setEndFromDate(String endFromDate) {
        this.endFromDate = endFromDate;
    }

    /**
     * @return the startToDate
     */
    public String getStartToDate() {
        return startToDate;
    }

    /**
     * @param startToDate
     *            the startToDate to set
     */
    public void setStartToDate(String startToDate) {
        this.startToDate = startToDate;
    }

    /**
     * @return the endToDate
     */
    public String getEndToDate() {
        return endToDate;
    }

    /**
     * @param endToDate
     *            the endToDate to set
     */
    public void setEndToDate(String endToDate) {
        this.endToDate = endToDate;
    }

    /**
     * @return the jobId
     */
    public String getJobId() {
        return jobId;
    }

    /**
     * @param jobId
     *            the jobId to set
     */
    public void setJobId(String jobId) {
        this.jobId = jobId;
    }

    /**
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * @param status
     *            the status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * @return the triggerType
     */
    public String getTriggerType() {
        return triggerType;
    }

    /**
     * @param triggerType
     *            the triggerType to set
     */
    public void setTriggerType(String triggerType) {
        this.triggerType = triggerType;
    }

    /**
     * @return the triggerInfo
     */
    public String getTriggerInfo() {
        return triggerInfo;
    }

    /**
     * @param triggerInfo
     *            the triggerInfo to set
     */
    public void setTriggerInfo(String triggerInfo) {
        this.triggerInfo = triggerInfo;
    }

    /**
     * @param filter
     *            the filter to set
     */
    public void setFilter(boolean filter) {
        this.filter = filter;
    }

    /**
     * @return the jobManager
     */
    public String getJobManager() {
        return jobManager;
    }

    /**
     * @param jobManager the jobManager to set
     */
    public void setJobManager(String jobManager) {
        this.jobManager = jobManager;
    }
}
